""" Automatically generated C-style module for pyGLFW """
from . import (
    ACCUM_ALPHA_BITS as GLFW_ACCUM_ALPHA_BITS,
    ACCUM_BLUE_BITS as GLFW_ACCUM_BLUE_BITS,
    ACCUM_GREEN_BITS as GLFW_ACCUM_GREEN_BITS,
    ACCUM_RED_BITS as GLFW_ACCUM_RED_BITS,
    ALPHA_BITS as GLFW_ALPHA_BITS,
    ANY_RELEASE_BEHAVIOR as GLFW_ANY_RELEASE_BEHAVIOR,
    API_UNAVAILABLE as GLFW_API_UNAVAILABLE,
    ARROW_CURSOR as GLFW_ARROW_CURSOR,
    AUTO_ICONIFY as GLFW_AUTO_ICONIFY,
    AUX_BUFFERS as GLFW_AUX_BUFFERS,
    BLUE_BITS as GLFW_BLUE_BITS,
    CENTER_CURSOR as GLFW_CENTER_CURSOR,
    CLIENT_API as GLFW_CLIENT_API,
    COCOA_CHDIR_RESOURCES as GLFW_COCOA_CHDIR_RESOURCES,
    COCOA_FRAME_NAME as GLFW_COCOA_FRAME_NAME,
    COCOA_GRAPHICS_SWITCHING as GLFW_COCOA_GRAPHICS_SWITCHING,
    COCOA_MENUBAR as GLFW_COCOA_MENUBAR,
    COCOA_RETINA_FRAMEBUFFER as GLFW_COCOA_RETINA_FRAMEBUFFER,
    CONNECTED as GLFW_CONNECTED,
    CONTEXT_CREATION_API as GLFW_CONTEXT_CREATION_API,
    CONTEXT_NO_ERROR as GLFW_CONTEXT_NO_ERROR,
    CONTEXT_RELEASE_BEHAVIOR as GLFW_CONTEXT_RELEASE_BEHAVIOR,
    CONTEXT_REVISION as GLFW_CONTEXT_REVISION,
    CONTEXT_ROBUSTNESS as GLFW_CONTEXT_ROBUSTNESS,
    CONTEXT_VERSION_MAJOR as GLFW_CONTEXT_VERSION_MAJOR,
    CONTEXT_VERSION_MINOR as GLFW_CONTEXT_VERSION_MINOR,
    CROSSHAIR_CURSOR as GLFW_CROSSHAIR_CURSOR,
    CURSOR as GLFW_CURSOR,
    CURSOR_DISABLED as GLFW_CURSOR_DISABLED,
    CURSOR_HIDDEN as GLFW_CURSOR_HIDDEN,
    CURSOR_NORMAL as GLFW_CURSOR_NORMAL,
    DECORATED as GLFW_DECORATED,
    DEPTH_BITS as GLFW_DEPTH_BITS,
    DISCONNECTED as GLFW_DISCONNECTED,
    DONT_CARE as GLFW_DONT_CARE,
    DOUBLEBUFFER as GLFW_DOUBLEBUFFER,
    EGL_CONTEXT_API as GLFW_EGL_CONTEXT_API,
    ERROR_REPORTING as GLFW_ERROR_REPORTING,
    FALSE as GLFW_FALSE,
    FLOATING as GLFW_FLOATING,
    FOCUSED as GLFW_FOCUSED,
    FOCUS_ON_SHOW as GLFW_FOCUS_ON_SHOW,
    FORMAT_UNAVAILABLE as GLFW_FORMAT_UNAVAILABLE,
    GAMEPAD_AXIS_LAST as GLFW_GAMEPAD_AXIS_LAST,
    GAMEPAD_AXIS_LEFT_TRIGGER as GLFW_GAMEPAD_AXIS_LEFT_TRIGGER,
    GAMEPAD_AXIS_LEFT_X as GLFW_GAMEPAD_AXIS_LEFT_X,
    GAMEPAD_AXIS_LEFT_Y as GLFW_GAMEPAD_AXIS_LEFT_Y,
    GAMEPAD_AXIS_RIGHT_TRIGGER as GLFW_GAMEPAD_AXIS_RIGHT_TRIGGER,
    GAMEPAD_AXIS_RIGHT_X as GLFW_GAMEPAD_AXIS_RIGHT_X,
    GAMEPAD_AXIS_RIGHT_Y as GLFW_GAMEPAD_AXIS_RIGHT_Y,
    GAMEPAD_BUTTON_A as GLFW_GAMEPAD_BUTTON_A,
    GAMEPAD_BUTTON_B as GLFW_GAMEPAD_BUTTON_B,
    GAMEPAD_BUTTON_BACK as GLFW_GAMEPAD_BUTTON_BACK,
    GAMEPAD_BUTTON_CIRCLE as GLFW_GAMEPAD_BUTTON_CIRCLE,
    GAMEPAD_BUTTON_CROSS as GLFW_GAMEPAD_BUTTON_CROSS,
    GAMEPAD_BUTTON_DPAD_DOWN as GLFW_GAMEPAD_BUTTON_DPAD_DOWN,
    GAMEPAD_BUTTON_DPAD_LEFT as GLFW_GAMEPAD_BUTTON_DPAD_LEFT,
    GAMEPAD_BUTTON_DPAD_RIGHT as GLFW_GAMEPAD_BUTTON_DPAD_RIGHT,
    GAMEPAD_BUTTON_DPAD_UP as GLFW_GAMEPAD_BUTTON_DPAD_UP,
    GAMEPAD_BUTTON_GUIDE as GLFW_GAMEPAD_BUTTON_GUIDE,
    GAMEPAD_BUTTON_LAST as GLFW_GAMEPAD_BUTTON_LAST,
    GAMEPAD_BUTTON_LEFT_BUMPER as GLFW_GAMEPAD_BUTTON_LEFT_BUMPER,
    GAMEPAD_BUTTON_LEFT_THUMB as GLFW_GAMEPAD_BUTTON_LEFT_THUMB,
    GAMEPAD_BUTTON_RIGHT_BUMPER as GLFW_GAMEPAD_BUTTON_RIGHT_BUMPER,
    GAMEPAD_BUTTON_RIGHT_THUMB as GLFW_GAMEPAD_BUTTON_RIGHT_THUMB,
    GAMEPAD_BUTTON_SQUARE as GLFW_GAMEPAD_BUTTON_SQUARE,
    GAMEPAD_BUTTON_START as GLFW_GAMEPAD_BUTTON_START,
    GAMEPAD_BUTTON_TRIANGLE as GLFW_GAMEPAD_BUTTON_TRIANGLE,
    GAMEPAD_BUTTON_X as GLFW_GAMEPAD_BUTTON_X,
    GAMEPAD_BUTTON_Y as GLFW_GAMEPAD_BUTTON_Y,
    GREEN_BITS as GLFW_GREEN_BITS,
    HAND_CURSOR as GLFW_HAND_CURSOR,
    HAT_CENTERED as GLFW_HAT_CENTERED,
    HAT_DOWN as GLFW_HAT_DOWN,
    HAT_LEFT as GLFW_HAT_LEFT,
    HAT_LEFT_DOWN as GLFW_HAT_LEFT_DOWN,
    HAT_LEFT_UP as GLFW_HAT_LEFT_UP,
    HAT_RIGHT as GLFW_HAT_RIGHT,
    HAT_RIGHT_DOWN as GLFW_HAT_RIGHT_DOWN,
    HAT_RIGHT_UP as GLFW_HAT_RIGHT_UP,
    HAT_UP as GLFW_HAT_UP,
    HOVERED as GLFW_HOVERED,
    HRESIZE_CURSOR as GLFW_HRESIZE_CURSOR,
    IBEAM_CURSOR as GLFW_IBEAM_CURSOR,
    ICONIFIED as GLFW_ICONIFIED,
    INVALID_ENUM as GLFW_INVALID_ENUM,
    INVALID_VALUE as GLFW_INVALID_VALUE,
    JOYSTICK_1 as GLFW_JOYSTICK_1,
    JOYSTICK_10 as GLFW_JOYSTICK_10,
    JOYSTICK_11 as GLFW_JOYSTICK_11,
    JOYSTICK_12 as GLFW_JOYSTICK_12,
    JOYSTICK_13 as GLFW_JOYSTICK_13,
    JOYSTICK_14 as GLFW_JOYSTICK_14,
    JOYSTICK_15 as GLFW_JOYSTICK_15,
    JOYSTICK_16 as GLFW_JOYSTICK_16,
    JOYSTICK_2 as GLFW_JOYSTICK_2,
    JOYSTICK_3 as GLFW_JOYSTICK_3,
    JOYSTICK_4 as GLFW_JOYSTICK_4,
    JOYSTICK_5 as GLFW_JOYSTICK_5,
    JOYSTICK_6 as GLFW_JOYSTICK_6,
    JOYSTICK_7 as GLFW_JOYSTICK_7,
    JOYSTICK_8 as GLFW_JOYSTICK_8,
    JOYSTICK_9 as GLFW_JOYSTICK_9,
    JOYSTICK_HAT_BUTTONS as GLFW_JOYSTICK_HAT_BUTTONS,
    JOYSTICK_LAST as GLFW_JOYSTICK_LAST,
    KEY_0 as GLFW_KEY_0,
    KEY_1 as GLFW_KEY_1,
    KEY_2 as GLFW_KEY_2,
    KEY_3 as GLFW_KEY_3,
    KEY_4 as GLFW_KEY_4,
    KEY_5 as GLFW_KEY_5,
    KEY_6 as GLFW_KEY_6,
    KEY_7 as GLFW_KEY_7,
    KEY_8 as GLFW_KEY_8,
    KEY_9 as GLFW_KEY_9,
    KEY_A as GLFW_KEY_A,
    KEY_APOSTROPHE as GLFW_KEY_APOSTROPHE,
    KEY_B as GLFW_KEY_B,
    KEY_BACKSLASH as GLFW_KEY_BACKSLASH,
    KEY_BACKSPACE as GLFW_KEY_BACKSPACE,
    KEY_C as GLFW_KEY_C,
    KEY_CAPS_LOCK as GLFW_KEY_CAPS_LOCK,
    KEY_COMMA as GLFW_KEY_COMMA,
    KEY_D as GLFW_KEY_D,
    KEY_DELETE as GLFW_KEY_DELETE,
    KEY_DOWN as GLFW_KEY_DOWN,
    KEY_E as GLFW_KEY_E,
    KEY_END as GLFW_KEY_END,
    KEY_ENTER as GLFW_KEY_ENTER,
    KEY_EQUAL as GLFW_KEY_EQUAL,
    KEY_ESCAPE as GLFW_KEY_ESCAPE,
    KEY_F as GLFW_KEY_F,
    KEY_F1 as GLFW_KEY_F1,
    KEY_F10 as GLFW_KEY_F10,
    KEY_F11 as GLFW_KEY_F11,
    KEY_F12 as GLFW_KEY_F12,
    KEY_F13 as GLFW_KEY_F13,
    KEY_F14 as GLFW_KEY_F14,
    KEY_F15 as GLFW_KEY_F15,
    KEY_F16 as GLFW_KEY_F16,
    KEY_F17 as GLFW_KEY_F17,
    KEY_F18 as GLFW_KEY_F18,
    KEY_F19 as GLFW_KEY_F19,
    KEY_F2 as GLFW_KEY_F2,
    KEY_F20 as GLFW_KEY_F20,
    KEY_F21 as GLFW_KEY_F21,
    KEY_F22 as GLFW_KEY_F22,
    KEY_F23 as GLFW_KEY_F23,
    KEY_F24 as GLFW_KEY_F24,
    KEY_F25 as GLFW_KEY_F25,
    KEY_F3 as GLFW_KEY_F3,
    KEY_F4 as GLFW_KEY_F4,
    KEY_F5 as GLFW_KEY_F5,
    KEY_F6 as GLFW_KEY_F6,
    KEY_F7 as GLFW_KEY_F7,
    KEY_F8 as GLFW_KEY_F8,
    KEY_F9 as GLFW_KEY_F9,
    KEY_G as GLFW_KEY_G,
    KEY_GRAVE_ACCENT as GLFW_KEY_GRAVE_ACCENT,
    KEY_H as GLFW_KEY_H,
    KEY_HOME as GLFW_KEY_HOME,
    KEY_I as GLFW_KEY_I,
    KEY_INSERT as GLFW_KEY_INSERT,
    KEY_J as GLFW_KEY_J,
    KEY_K as GLFW_KEY_K,
    KEY_KP_0 as GLFW_KEY_KP_0,
    KEY_KP_1 as GLFW_KEY_KP_1,
    KEY_KP_2 as GLFW_KEY_KP_2,
    KEY_KP_3 as GLFW_KEY_KP_3,
    KEY_KP_4 as GLFW_KEY_KP_4,
    KEY_KP_5 as GLFW_KEY_KP_5,
    KEY_KP_6 as GLFW_KEY_KP_6,
    KEY_KP_7 as GLFW_KEY_KP_7,
    KEY_KP_8 as GLFW_KEY_KP_8,
    KEY_KP_9 as GLFW_KEY_KP_9,
    KEY_KP_ADD as GLFW_KEY_KP_ADD,
    KEY_KP_DECIMAL as GLFW_KEY_KP_DECIMAL,
    KEY_KP_DIVIDE as GLFW_KEY_KP_DIVIDE,
    KEY_KP_ENTER as GLFW_KEY_KP_ENTER,
    KEY_KP_EQUAL as GLFW_KEY_KP_EQUAL,
    KEY_KP_MULTIPLY as GLFW_KEY_KP_MULTIPLY,
    KEY_KP_SUBTRACT as GLFW_KEY_KP_SUBTRACT,
    KEY_L as GLFW_KEY_L,
    KEY_LAST as GLFW_KEY_LAST,
    KEY_LEFT as GLFW_KEY_LEFT,
    KEY_LEFT_ALT as GLFW_KEY_LEFT_ALT,
    KEY_LEFT_BRACKET as GLFW_KEY_LEFT_BRACKET,
    KEY_LEFT_CONTROL as GLFW_KEY_LEFT_CONTROL,
    KEY_LEFT_SHIFT as GLFW_KEY_LEFT_SHIFT,
    KEY_LEFT_SUPER as GLFW_KEY_LEFT_SUPER,
    KEY_M as GLFW_KEY_M,
    KEY_MENU as GLFW_KEY_MENU,
    KEY_MINUS as GLFW_KEY_MINUS,
    KEY_N as GLFW_KEY_N,
    KEY_NUM_LOCK as GLFW_KEY_NUM_LOCK,
    KEY_O as GLFW_KEY_O,
    KEY_P as GLFW_KEY_P,
    KEY_PAGE_DOWN as GLFW_KEY_PAGE_DOWN,
    KEY_PAGE_UP as GLFW_KEY_PAGE_UP,
    KEY_PAUSE as GLFW_KEY_PAUSE,
    KEY_PERIOD as GLFW_KEY_PERIOD,
    KEY_PRINT_SCREEN as GLFW_KEY_PRINT_SCREEN,
    KEY_Q as GLFW_KEY_Q,
    KEY_R as GLFW_KEY_R,
    KEY_RIGHT as GLFW_KEY_RIGHT,
    KEY_RIGHT_ALT as GLFW_KEY_RIGHT_ALT,
    KEY_RIGHT_BRACKET as GLFW_KEY_RIGHT_BRACKET,
    KEY_RIGHT_CONTROL as GLFW_KEY_RIGHT_CONTROL,
    KEY_RIGHT_SHIFT as GLFW_KEY_RIGHT_SHIFT,
    KEY_RIGHT_SUPER as GLFW_KEY_RIGHT_SUPER,
    KEY_S as GLFW_KEY_S,
    KEY_SCROLL_LOCK as GLFW_KEY_SCROLL_LOCK,
    KEY_SEMICOLON as GLFW_KEY_SEMICOLON,
    KEY_SLASH as GLFW_KEY_SLASH,
    KEY_SPACE as GLFW_KEY_SPACE,
    KEY_T as GLFW_KEY_T,
    KEY_TAB as GLFW_KEY_TAB,
    KEY_U as GLFW_KEY_U,
    KEY_UNKNOWN as GLFW_KEY_UNKNOWN,
    KEY_UP as GLFW_KEY_UP,
    KEY_V as GLFW_KEY_V,
    KEY_W as GLFW_KEY_W,
    KEY_WORLD_1 as GLFW_KEY_WORLD_1,
    KEY_WORLD_2 as GLFW_KEY_WORLD_2,
    KEY_X as GLFW_KEY_X,
    KEY_Y as GLFW_KEY_Y,
    KEY_Z as GLFW_KEY_Z,
    LOCK_KEY_MODS as GLFW_LOCK_KEY_MODS,
    LOSE_CONTEXT_ON_RESET as GLFW_LOSE_CONTEXT_ON_RESET,
    MAXIMIZED as GLFW_MAXIMIZED,
    MOD_ALT as GLFW_MOD_ALT,
    MOD_CAPS_LOCK as GLFW_MOD_CAPS_LOCK,
    MOD_CONTROL as GLFW_MOD_CONTROL,
    MOD_NUM_LOCK as GLFW_MOD_NUM_LOCK,
    MOD_SHIFT as GLFW_MOD_SHIFT,
    MOD_SUPER as GLFW_MOD_SUPER,
    MOUSE_BUTTON_1 as GLFW_MOUSE_BUTTON_1,
    MOUSE_BUTTON_2 as GLFW_MOUSE_BUTTON_2,
    MOUSE_BUTTON_3 as GLFW_MOUSE_BUTTON_3,
    MOUSE_BUTTON_4 as GLFW_MOUSE_BUTTON_4,
    MOUSE_BUTTON_5 as GLFW_MOUSE_BUTTON_5,
    MOUSE_BUTTON_6 as GLFW_MOUSE_BUTTON_6,
    MOUSE_BUTTON_7 as GLFW_MOUSE_BUTTON_7,
    MOUSE_BUTTON_8 as GLFW_MOUSE_BUTTON_8,
    MOUSE_BUTTON_LAST as GLFW_MOUSE_BUTTON_LAST,
    MOUSE_BUTTON_LEFT as GLFW_MOUSE_BUTTON_LEFT,
    MOUSE_BUTTON_MIDDLE as GLFW_MOUSE_BUTTON_MIDDLE,
    MOUSE_BUTTON_RIGHT as GLFW_MOUSE_BUTTON_RIGHT,
    NATIVE_CONTEXT_API as GLFW_NATIVE_CONTEXT_API,
    NORMALIZE_GAMMA_RAMPS as GLFW_NORMALIZE_GAMMA_RAMPS,
    NOT_INITIALIZED as GLFW_NOT_INITIALIZED,
    NO_API as GLFW_NO_API,
    NO_CURRENT_CONTEXT as GLFW_NO_CURRENT_CONTEXT,
    NO_ERROR as GLFW_NO_ERROR,
    NO_RESET_NOTIFICATION as GLFW_NO_RESET_NOTIFICATION,
    NO_ROBUSTNESS as GLFW_NO_ROBUSTNESS,
    NO_WINDOW_CONTEXT as GLFW_NO_WINDOW_CONTEXT,
    OPENGL_ANY_PROFILE as GLFW_OPENGL_ANY_PROFILE,
    OPENGL_API as GLFW_OPENGL_API,
    OPENGL_COMPAT_PROFILE as GLFW_OPENGL_COMPAT_PROFILE,
    OPENGL_CORE_PROFILE as GLFW_OPENGL_CORE_PROFILE,
    OPENGL_DEBUG_CONTEXT as GLFW_OPENGL_DEBUG_CONTEXT,
    OPENGL_ES_API as GLFW_OPENGL_ES_API,
    OPENGL_FORWARD_COMPAT as GLFW_OPENGL_FORWARD_COMPAT,
    OPENGL_PROFILE as GLFW_OPENGL_PROFILE,
    OSMESA_CONTEXT_API as GLFW_OSMESA_CONTEXT_API,
    OUT_OF_MEMORY as GLFW_OUT_OF_MEMORY,
    PLATFORM_ERROR as GLFW_PLATFORM_ERROR,
    PRESS as GLFW_PRESS,
    RAW_MOUSE_MOTION as GLFW_RAW_MOUSE_MOTION,
    RED_BITS as GLFW_RED_BITS,
    REFRESH_RATE as GLFW_REFRESH_RATE,
    RELEASE as GLFW_RELEASE,
    RELEASE_BEHAVIOR_FLUSH as GLFW_RELEASE_BEHAVIOR_FLUSH,
    RELEASE_BEHAVIOR_NONE as GLFW_RELEASE_BEHAVIOR_NONE,
    REPEAT as GLFW_REPEAT,
    RESIZABLE as GLFW_RESIZABLE,
    SAMPLES as GLFW_SAMPLES,
    SCALE_TO_MONITOR as GLFW_SCALE_TO_MONITOR,
    SRGB_CAPABLE as GLFW_SRGB_CAPABLE,
    STENCIL_BITS as GLFW_STENCIL_BITS,
    STEREO as GLFW_STEREO,
    STICKY_KEYS as GLFW_STICKY_KEYS,
    STICKY_MOUSE_BUTTONS as GLFW_STICKY_MOUSE_BUTTONS,
    TRANSPARENT_FRAMEBUFFER as GLFW_TRANSPARENT_FRAMEBUFFER,
    TRUE as GLFW_TRUE,
    VERSION_MAJOR as GLFW_VERSION_MAJOR,
    VERSION_MINOR as GLFW_VERSION_MINOR,
    VERSION_REVISION as GLFW_VERSION_REVISION,
    VERSION_UNAVAILABLE as GLFW_VERSION_UNAVAILABLE,
    VISIBLE as GLFW_VISIBLE,
    VRESIZE_CURSOR as GLFW_VRESIZE_CURSOR,
    X11_CLASS_NAME as GLFW_X11_CLASS_NAME,
    X11_INSTANCE_NAME as GLFW_X11_INSTANCE_NAME,
    create_cursor as glfwCreateCursor,
    create_standard_cursor as glfwCreateStandardCursor,
    create_window as glfwCreateWindow,
    create_window_surface as glfwCreateWindowSurface,
    default_window_hints as glfwDefaultWindowHints,
    destroy_cursor as glfwDestroyCursor,
    destroy_window as glfwDestroyWindow,
    extension_supported as glfwExtensionSupported,
    focus_window as glfwFocusWindow,
    get_clipboard_string as glfwGetClipboardString,
    get_current_context as glfwGetCurrentContext,
    get_cursor_pos as glfwGetCursorPos,
    get_error as glfwGetError,
    get_framebuffer_size as glfwGetFramebufferSize,
    get_gamepad_name as glfwGetGamepadName,
    get_gamepad_state as glfwGetGamepadState,
    get_gamma_ramp as glfwGetGammaRamp,
    get_input_mode as glfwGetInputMode,
    get_instance_proc_address as glfwGetInstanceProcAddress,
    get_joystick_axes as glfwGetJoystickAxes,
    get_joystick_buttons as glfwGetJoystickButtons,
    get_joystick_guid as glfwGetJoystickGUID,
    get_joystick_hats as glfwGetJoystickHats,
    get_joystick_name as glfwGetJoystickName,
    get_joystick_user_pointer as glfwGetJoystickUserPointer,
    get_key as glfwGetKey,
    get_key_name as glfwGetKeyName,
    get_key_scancode as glfwGetKeyScancode,
    get_monitor_content_scale as glfwGetMonitorContentScale,
    get_monitor_name as glfwGetMonitorName,
    get_monitor_physical_size as glfwGetMonitorPhysicalSize,
    get_monitor_pos as glfwGetMonitorPos,
    get_monitor_user_pointer as glfwGetMonitorUserPointer,
    get_monitor_workarea as glfwGetMonitorWorkarea,
    get_monitors as glfwGetMonitors,
    get_mouse_button as glfwGetMouseButton,
    get_physical_device_presentation_support as glfwGetPhysicalDevicePresentationSupport,
    get_primary_monitor as glfwGetPrimaryMonitor,
    get_proc_address as glfwGetProcAddress,
    get_required_instance_extensions as glfwGetRequiredInstanceExtensions,
    get_time as glfwGetTime,
    get_timer_frequency as glfwGetTimerFrequency,
    get_timer_value as glfwGetTimerValue,
    get_version as glfwGetVersion,
    get_version_string as glfwGetVersionString,
    get_video_mode as glfwGetVideoMode,
    get_video_modes as glfwGetVideoModes,
    get_window_attrib as glfwGetWindowAttrib,
    get_window_content_scale as glfwGetWindowContentScale,
    get_window_frame_size as glfwGetWindowFrameSize,
    get_window_monitor as glfwGetWindowMonitor,
    get_window_opacity as glfwGetWindowOpacity,
    get_window_pos as glfwGetWindowPos,
    get_window_size as glfwGetWindowSize,
    get_window_user_pointer as glfwGetWindowUserPointer,
    hide_window as glfwHideWindow,
    iconify_window as glfwIconifyWindow,
    init as glfwInit,
    init_hint as glfwInitHint,
    joystick_is_gamepad as glfwJoystickIsGamepad,
    joystick_present as glfwJoystickPresent,
    make_context_current as glfwMakeContextCurrent,
    maximize_window as glfwMaximizeWindow,
    poll_events as glfwPollEvents,
    post_empty_event as glfwPostEmptyEvent,
    raw_mouse_motion_supported as glfwRawMouseMotionSupported,
    request_window_attention as glfwRequestWindowAttention,
    restore_window as glfwRestoreWindow,
    set_char_callback as glfwSetCharCallback,
    set_char_mods_callback as glfwSetCharModsCallback,
    set_clipboard_string as glfwSetClipboardString,
    set_cursor as glfwSetCursor,
    set_cursor_enter_callback as glfwSetCursorEnterCallback,
    set_cursor_pos as glfwSetCursorPos,
    set_cursor_pos_callback as glfwSetCursorPosCallback,
    set_drop_callback as glfwSetDropCallback,
    set_error_callback as glfwSetErrorCallback,
    set_framebuffer_size_callback as glfwSetFramebufferSizeCallback,
    set_gamma as glfwSetGamma,
    set_gamma_ramp as glfwSetGammaRamp,
    set_input_mode as glfwSetInputMode,
    set_joystick_callback as glfwSetJoystickCallback,
    set_joystick_user_pointer as glfwSetJoystickUserPointer,
    set_key_callback as glfwSetKeyCallback,
    set_monitor_callback as glfwSetMonitorCallback,
    set_monitor_user_pointer as glfwSetMonitorUserPointer,
    set_mouse_button_callback as glfwSetMouseButtonCallback,
    set_scroll_callback as glfwSetScrollCallback,
    set_time as glfwSetTime,
    set_window_aspect_ratio as glfwSetWindowAspectRatio,
    set_window_attrib as glfwSetWindowAttrib,
    set_window_close_callback as glfwSetWindowCloseCallback,
    set_window_content_scale_callback as glfwSetWindowContentScaleCallback,
    set_window_focus_callback as glfwSetWindowFocusCallback,
    set_window_icon as glfwSetWindowIcon,
    set_window_iconify_callback as glfwSetWindowIconifyCallback,
    set_window_maximize_callback as glfwSetWindowMaximizeCallback,
    set_window_monitor as glfwSetWindowMonitor,
    set_window_opacity as glfwSetWindowOpacity,
    set_window_pos as glfwSetWindowPos,
    set_window_pos_callback as glfwSetWindowPosCallback,
    set_window_refresh_callback as glfwSetWindowRefreshCallback,
    set_window_should_close as glfwSetWindowShouldClose,
    set_window_size as glfwSetWindowSize,
    set_window_size_callback as glfwSetWindowSizeCallback,
    set_window_size_limits as glfwSetWindowSizeLimits,
    set_window_title as glfwSetWindowTitle,
    set_window_user_pointer as glfwSetWindowUserPointer,
    show_window as glfwShowWindow,
    swap_buffers as glfwSwapBuffers,
    swap_interval as glfwSwapInterval,
    terminate as glfwTerminate,
    update_gamepad_mappings as glfwUpdateGamepadMappings,
    vulkan_supported as glfwVulkanSupported,
    wait_events as glfwWaitEvents,
    wait_events_timeout as glfwWaitEventsTimeout,
    window_hint as glfwWindowHint,
    window_hint_string as glfwWindowHintString,
    window_should_close as glfwWindowShouldClose,
)
